@@ -142,11 +142,23 @@ class Container(dict):
         '''
         self._observers[safe_root(dotkey)].add(view)
 
+    def __contains__(self, key):
+        found = super().__contains__(key)
+        if found:
+            return True
+        if is_root(key):
+            return False
+        try:
+            dct = self.get_dct(key)
+            return True
+        except KeyError:
+            return False
+
     def __missing__(self, key):
         try:
             ret = self.get_dct(key)
         except:
-            return super().__missing__()
+            raise KeyError("Key '" + str(key) + "' not found. Check aliases.")
         return ret
 
     def get_dct(self, dotkey):
@@ -161,15 +173,14 @@ class Container(dict):
         '''
         if is_root(dotkey):
             return self.copy()
-        n = len(dotkey)
         out = {}
+        s = dotkey + '.'  # Force it to be a dot
+        n = len(s)
         for key, val in self.items():
-            if key[:n] == dotkey and len(key) > n+1:
-                # Check it's definately a dot after the dotkey before adding it
-                # Otherwise it might add e.g. underscored dotkeys.
-                if key[n] == '.':
-                    k = key[n+1:]
-                    out[k] = val
+            if key.startswith(s):
+                out[key[n:]] = val
+        if len(out) == 0:
+            raise KeyError("'" + dotkey + "'")
         return out
 
     def update_observers(self, dotkey, val):
